import { Component, ChangeDetectionStrategy, Input, ChangeDetectorRef, forwardRef, Output, EventEmitter } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
var CheckboxComponent = (function () {
    function CheckboxComponent(changeDetectorRef) {
        this.changeDetectorRef = changeDetectorRef;
        this.disabled = false;
        this.checkedValue = true;
        this.unCheckedValue = false;
        this.valueChange = new EventEmitter();
        this.onChange = function (_) { return null; };
        this.onTouched = function () { return null; };
    }
    CheckboxComponent.prototype.writeValue = function (obj) {
        this.value = obj;
        this.changeDetectorRef.markForCheck();
    };
    CheckboxComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    CheckboxComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    CheckboxComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    CheckboxComponent.prototype.onCheckBoxChange = function (checkbox) {
        this.onTouched();
        if (checkbox.checked) {
            this.value = this.checkedValue;
        }
        else {
            this.value = this.unCheckedValue;
        }
        this.onChange(this.value);
        this.valueChange.emit(this.value);
    };
    CheckboxComponent.prototype.isChecked = function () {
        return this.value === this.checkedValue;
    };
    return CheckboxComponent;
}());
export { CheckboxComponent };
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 're-checkbox',
                template: "\n    <label><input #checkbox type=\"checkbox\" [checked]=\"isChecked()\" [disabled]=\"disabled\" (change)=\"onCheckBoxChange(checkbox)\">{{label}}</label>\n  ",
                styles: ["\n\n  "],
                changeDetection: ChangeDetectionStrategy.OnPush,
                exportAs: 'checkbox',
                host: { '[class]': '(cssClass ? cssClass : "") + " checkbox"' },
                providers: [{
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(function () { return CheckboxComponent; }),
                        multi: true
                    }]
            },] },
];
/** @nocollapse */
CheckboxComponent.ctorParameters = function () { return [
    { type: ChangeDetectorRef, },
]; };
CheckboxComponent.propDecorators = {
    'disabled': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'label': [{ type: Input },],
    'checkedValue': [{ type: Input },],
    'unCheckedValue': [{ type: Input },],
    'valueChange': [{ type: Output },],
};
//# sourceMappingURL=checkbox.component.js.map